@@ -3,13 +3,12 @@
 #include <rapidjson/istreamwrapper.h>
 
 #include "geojsonsf/geojsonsf.h"
-#include "geojsonsf/geojson_to_sf.h"
-#include "geojsonsf/geojson_sfc.h"
-#include "geojsonsf/geojson_sfg.h"
-#include "geojsonsf/geojson_properties.h"
+#include "geojsonsf/geojson/geojson_to_sf.hpp"
+#include "geojsonsf/sf/sfc/geojson_sfc.hpp"
+#include "geojsonsf/sf/sfg/geojson_sfg.hpp"
+#include "geojsonsf/geojson/geojson_properties.hpp"
 #include <fstream>
 
-using namespace Rcpp;
 using namespace rapidjson;
 
 Rcpp::StringVector buffer_string(std::string file) {
@@ -21,12 +20,12 @@ Rcpp::StringVector buffer_string(std::string file) {
 
 // [[Rcpp::export]]
 Rcpp::List rcpp_read_sfc_file(std::string file, bool flatten_geometries) {
-  return create_sfc(buffer_string(file), flatten_geometries);
+  return geojsonsf::sf::create_sfc(buffer_string(file), flatten_geometries);
 }
 
 
 // [[Rcpp::export]]
 Rcpp::List rcpp_read_sf_file(std::string file, bool flatten_geometries) {
-  return generic_geojson_to_sf(buffer_string(file), flatten_geometries);
+  return geojsonsf::sf::generic_geojson_to_sf(buffer_string(file), flatten_geometries);
 }
 
